History
=======

0.0.2 (2014-04-14)
------------------

* Added more documentation for simple usage.
* Worked on installation utilities.
* Still no tests :(.

0.0.1 (2014-04-14)
------------------

* Initial release.
